#include "config.h"

#ifdef HAVE_UNISTD_H
#include <unistd.h>
#endif

#ifdef HAVE_STRING_H
#include <string.h>
#endif

#include <stdio.h>
#include <assert.h>

#include "types.h"
#include "error.h"
#include "fd.h"
#include "io.h"
#include "display.h"
#include "args.h"

/*
#define PRINT_DEBUG
#define PRINT_ERRORS
*/

#ifdef PRINT_DEBUG
void print(void)
{
	fprintf(stderr, "d.start_time == %llu\n", (unsigned long long)d.start_time);
	fprintf(stderr, "d.total_time == %llu\n", (unsigned long long)d.total_time);
	fprintf(stderr, "d.current_time == %llu\n", (unsigned long long)d.current_time);
	fprintf(stderr, "d.elapsed_time == %llu\n", (unsigned long long)d.elapsed_time);
	fprintf(stderr, "d.percent_complete == %d\n", (int)d.percent_complete);
	fprintf(stderr, "d.display_interval == %d\n", d.display_interval);
	fprintf(stderr, "d.overtime_flag == %d\n", d.overtime_flag);
	fprintf(stderr, "d.k == %d\n", d.k);
	fprintf(stderr, "d.twiddle == %d\n", d.twiddle);
	fprintf(stderr, "d.screen_width == %d\n", d.screen_width);
	fprintf(stderr, "d.manual_width == %d\n", d.manual_width);
	fprintf(stderr, "d.display_twiddle == %d\n", d.display_twiddle);
	fprintf(stderr, "d.display_datacount == %d\n", d.display_datacount);
	fprintf(stderr, "d.display_throughput == %d\n", d.display_throughput);
	fprintf(stderr, "d.display_time == %d\n", d.display_time);
	fprintf(stderr, "d.display_percent == %d\n", d.display_percent);
	fprintf(stderr, "d.display_bar == %d\n", d.display_bar);
	fprintf(stderr, "d.display_summary == %d\n", d.display_summary);
	fprintf(stderr, "d.display_ansi == %d\n", d.display_ansi);

	fprintf(stderr, "d.twiddle_fg_color == %s\n",
		(d.twiddle_fg_color != 0) ? d.twiddle_fg_color+1 : "");
	fprintf(stderr, "d.twiddle_bg_color == %s\n",
		(d.twiddle_bg_color != 0) ? d.twiddle_bg_color+1 : "");
	fprintf(stderr, "d.twiddle_fg_bold == %d\n", d.twiddle_fg_bold);

	fprintf(stderr, "d.datacount_fg_color == %s\n",
		(d.datacount_fg_color != 0) ? d.datacount_fg_color+1 : "");
	fprintf(stderr, "d.datacount_bg_color == %s\n",
		(d.datacount_bg_color != 0) ? d.datacount_bg_color+1 : "");
	fprintf(stderr, "d.datacount_fg_bold == %d\n", d.datacount_fg_bold);

	fprintf(stderr, "d.throughput_label_fg_color == %s\n",
		(d.throughput_label_fg_color != 0) ? d.throughput_label_fg_color+1 : "");
	fprintf(stderr, "d.throughput_label_bg_color == %s\n",
		(d.throughput_label_bg_color != 0) ? d.throughput_label_bg_color+1 : "");
	fprintf(stderr, "d.throughput_label_fg_bold == %d\n", d.throughput_label_fg_bold);

	fprintf(stderr, "d.throughput_fg_color == %s\n",
		(d.throughput_fg_color != 0) ? d.throughput_fg_color+1 : "");
	fprintf(stderr, "d.throughput_bg_color == %s\n",
		(d.throughput_bg_color != 0) ? d.throughput_bg_color+1 : "");
	fprintf(stderr, "d.throughput_fg_bold == %d\n", d.throughput_fg_bold);

	fprintf(stderr, "d.time_label_fg_color == %s\n",
		(d.time_label_fg_color != 0) ? d.time_label_fg_color+1 : "");
	fprintf(stderr, "d.time_label_bg_color == %s\n",
		(d.time_label_bg_color != 0) ? d.time_label_bg_color+1 : "");
	fprintf(stderr, "d.time_label_fg_bold == %d\n", d.time_label_fg_bold);

	fprintf(stderr, "d.time_fg_color == %s\n",
		(d.time_fg_color != 0) ? d.time_fg_color+1 : "");
	fprintf(stderr, "d.time_bg_color == %s\n",
		(d.time_bg_color != 0) ? d.time_bg_color+1 : "");
	fprintf(stderr, "d.time_fg_bold == %d\n", d.time_fg_bold);

	fprintf(stderr, "d.percent_fg_color == %s\n",
		(d.percent_fg_color != 0) ? d.percent_fg_color+1 : "");
	fprintf(stderr, "d.percent_bg_color == %s\n",
		(d.percent_bg_color != 0) ? d.percent_bg_color+1 : "");
	fprintf(stderr, "d.percent_fg_bold == %d\n", d.percent_fg_bold);

	fprintf(stderr, "d.barbrace_fg_color == %s\n",
		(d.barbrace_fg_color != 0) ? d.barbrace_fg_color+1 : "");
	fprintf(stderr, "d.barbrace_bg_color == %s\n",
		(d.barbrace_bg_color != 0) ? d.barbrace_bg_color+1 : "");
	fprintf(stderr, "d.barbrace_fg_bold == %d\n", d.barbrace_fg_bold);

	fprintf(stderr, "d.bar_fg_color == %s\n",
		(d.bar_fg_color != 0) ? d.bar_fg_color+1 : "");
	fprintf(stderr, "d.bar_bg_color == %s\n",
		(d.bar_bg_color != 0) ? d.bar_bg_color+1 : "");
	fprintf(stderr, "d.bar_fg_bold == %d\n", d.bar_fg_bold);

	fprintf(stderr, "io.in == %d\n", io.in);
	fprintf(stderr, "io.out == %d\n", io.out);
	fprintf(stderr, "io.in_ready == %d\n", io.in_ready);
	fprintf(stderr, "io.out_ready == %d\n", io.out_ready);
	fprintf(stderr, "io.eof_in == %d\n", io.eof_in);
	fprintf(stderr, "io.eof_out == %d\n", io.eof_out);
	fprintf(stderr, "io.buffer_size == %llu\n", (unsigned long long)io.buffer_size);
	fprintf(stderr, "io.buffer == %p\n", io.buffer);
	fprintf(stderr, "io.watermark == %d\n", io.watermark);
	fprintf(stderr, "io.last_read == %llu\n", (unsigned long long)io.last_read);
	fprintf(stderr, "io.last_write == %llu\n", (unsigned long long)io.last_write);
	fprintf(stderr, "io.total_read == %llu\n", (unsigned long long)io.total_read);
	fprintf(stderr, "io.total_write == %llu\n", (unsigned long long)io.total_write);
	fprintf(stderr, "io.total_size == %llu\n", (unsigned long long)io.total_size);
	fprintf(stderr, "io.total_size_known == %d\n", io.total_size_known);
	fprintf(stderr, "io.timeout == %llu\n", (unsigned long long)io.timeout);
}
#endif

int test_parse(FILE *out, char* s, int r, uint64 n)
{
	int result_r;
	uint64 result_n;

#ifdef PRINT_ERRORS
	if (r != 0) {
		fprintf(out, "\n");
		fprintf(out, "You should see an error message here:\n");
		fprintf(out, "---[ BEGIN ]-----------------------------------\n");
	}
#endif
	result_r = parse_num(out, s, &result_n, 0, MAX_UINT64);
#ifdef PRINT_ERRORS
	if (r != 0) {
		fprintf(out, "---[ END ]-------------------------------------\n");
	}
#endif
	if ((result_r != r) || (result_n != n)) {
#ifdef PRINT_ERRORS
		fprintf(out, "*** ERROR: Number parse test failed on: %s\n", s);
		fprintf(out, "           Expected result: %d  Got: %d\n", r, result_r);
		fprintf(out, "           Expected number: %llu\n", n);
		fprintf(out, "                Got number: %llu\n", result_n);
#endif
		return(0);
	}
	return(1);
}

int test_parse_rc(FILE *out, int r)
{
	int result_r = 0;

#ifdef PRINT_ERRORS
	if (r != 0) {
		fprintf(out, "\n");
		fprintf(out, "You should see an error message here: \n");
		fprintf(out, "---[ BEGIN ]-----------------------------------\n");
	}
#endif
	result_r = parse_rcfile(out,"./test-rcfile.txt");
#ifdef PRINT_ERRORS
	if (r != 0) {
		fprintf(out, "---[ END ]-------------------------------------\n");
	}
#endif

	return(r == result_r);
}


void test1(FILE *out)
{
	uint64 k = 1000;
	uint64 m = k*k;
	uint64 e;

	displayInit();
	ioInit();
	d.k = k;

	assert(test_parse(out, "", 0, 0));
	assert(test_parse(out, "m", 1, 0));
	assert(test_parse(out, "1m1", 1, 0));
	assert(test_parse(out, ".m", 1, 0));
	assert(test_parse(out, ".0m", 0, 0));
	assert(test_parse(out, ".1m", 0, 0.1*m));
	assert(test_parse(out, ".10m", 0, 0.1*m));
	assert(test_parse(out, "1024.38m", 0, 1024.38*m));
	assert(test_parse(out, "1024.380m", 0, 1024.38*m));
	assert(test_parse(out, "1024.38002m", 0, 1024.38002*m));

	/*
	 * The following workaround avoids the following compiler warning:
	 * "warning: decimal constant is so large that it is unsigned" on
	 * the number 18446744073709551615
	 */
	e = 18;
	e *= 1000;
	e += 446;
	e *= 1000;
	e += 744;
	e *= 1000;
	e += 73;
	e *= 1000;
	e += 709;
	e *= 1000;
	e += 551;
	e *= 1000;
	e += 615;
	assert(test_parse(out, "18446744073709551615", 0, e));

	assert(test_parse(out, "18446744073709551616", 1, 0));
	assert(test_parse(out, "15.9999999999k", 0, 16000));

	/*
	 * The following workaround avoids the following compiler warning:
	 * "warning: decimal constant is so large that it is unsigned" on
	 * the number 15999999999999999900
	 */
	e = 15;
	e *= 1000;
	e += 999;
	e *= 1000;
	e += 999;
	e *= 1000;
	e += 999;
	e *= 1000;
	e += 999;
	e *= 1000;
	e += 999;
	e *= 1000;
	e += 900;
	assert(test_parse(out, "15.9999999999999999e", 0, e));

	/*
	 * The following workaround avoids the following compiler warning:
	 * "warning: decimal constant is so large that it is unsigned" on
	 * the number 15999999999999999999
	 */
	e = 15;
	e *= 1000;
	e += 999;
	e *= 1000;
	e += 999;
	e *= 1000;
	e += 999;
	e *= 1000;
	e += 999;
	e *= 1000;
	e += 999;
	e *= 1000;
	e += 999;
	assert(test_parse(out, "15.999999999999999999e", 0, e));

	assert(test_parse(out, "18.44674407370955161e", 0, MAX_UINT64/10*10));
}

void test2(FILE *out)
{
	uint64 k = 1024;
	uint64 e;

	displayInit();
	ioInit();
	d.k = k;

	assert(test_parse(out, "", 0, 0));
	assert(test_parse(out, "m", 1, 0));
	assert(test_parse(out, "1m1", 1, 0));
	assert(test_parse(out, ".m", 1, 0));
	assert(test_parse(out, ".0m", 0, 0));
	assert(test_parse(out, ".1m", 0, 104858));
	assert(test_parse(out, ".10m", 0, 104858));
	assert(test_parse(out, "1024.38m", 0, 1074140283));
	assert(test_parse(out, "1024.380m", 0, 1074140283));
	assert(test_parse(out, "1024.38002m", 0, 1074140304));

	/*
	 * The following workaround avoids the following compiler warning:
	 * "warning: decimal constant is so large that it is unsigned" on
	 * the number 18446744073709551615
	 */
	e = 18;
	e *= 1000;
	e += 446;
	e *= 1000;
	e += 744;
	e *= 1000;
	e += 73;
	e *= 1000;
	e += 709;
	e *= 1000;
	e += 551;
	e *= 1000;
	e += 615;
	assert(test_parse(out, "18446744073709551615", 0, e));
	assert(test_parse(out, "18446744073709551616", 1, 0));
	assert(test_parse(out, "15.9999999999k", 0, 16384));

	/*
	 * The following workaround avoids the following compiler warning:
	 * "warning: decimal constant is so large that it is unsigned" on
	 * the number 18446744073709551500
	 */
	e = 18;
	e *= 1000;
	e += 446;
	e *= 1000;
	e += 744;
	e *= 1000;
	e += 73;
	e *= 1000;
	e += 709;
	e *= 1000;
	e += 551;
	e *= 1000;
	e += 500;
	assert(test_parse(out, "15.9999999999999999e", 0, e));

	/*
	 * The following workaround avoids the following compiler warning:
	 * "warning: decimal constant is so large that it is unsigned" on
	 * the number 18446744073709551614
	 */
	e = 18;
	e *= 1000;
	e += 446;
	e *= 1000;
	e += 744;
	e *= 1000;
	e += 73;
	e *= 1000;
	e += 709;
	e *= 1000;
	e += 551;
	e *= 1000;
	e += 614;
	assert(test_parse(out, "15.999999999999999999e", 0, e));

	/*
	 * The following workaround avoids the following compiler warning:
	 * "warning: decimal constant is so large that it is unsigned"
	 */
	e = 18;
	e *= 1000;
	e += 446;
	e *= 1000;
	e += 744;
	e *= 1000;
	e += 73;
	e *= 1000;
	e += 709;
	e *= 1000;
	e += 551;
	e *= 1000;
	e += 614;
	assert(test_parse(out, "15.99999999999999999913e", 0, e));
}

void test3(FILE* out)
{
	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test4(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test5(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "-if";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 1);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test6(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "/dev/null";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 1);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test7(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "-if";
	argv[argc++] = "/dev/null";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in != 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test8(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "-of";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 1);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test9(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "-of";
	argv[argc++] = "/dev/null";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out != 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test10(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "-s";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 1);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test11(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "-s";
	argv[argc++] = "/dev/null";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test12(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "-s";
	argv[argc++] = "1024.38002m";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 1074140304);
	assert(io.total_size_known == 1);
	assert(io.timeout == 250000);
}

void test13(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "-bs";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 1);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test14(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "-bs";
	argv[argc++] = "/dev/null";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test15(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "-bs";
	argv[argc++] = "1024.38002m";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1074140304);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test16(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "-i";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 1);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test17(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "-i";
	argv[argc++] = "/dev/null";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test18(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "-i";
	argv[argc++] = "1024.38002m";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test19(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "-i";
	argv[argc++] = "1024.38002";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test20(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "-i";
	argv[argc++] = "30";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 30);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test21(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "-t";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 1);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test22(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "-t";
	argv[argc++] = "/dev/null";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test23(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "-t";
	argv[argc++] = "1024.38002m";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test24(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "-t";
	argv[argc++] = "1024.38002";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test25(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "-t";
	argv[argc++] = "30";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 30);
}

void test26(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "-k";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 1);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test27(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "-k";
	argv[argc++] = "10";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 1);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test28(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "-k";
	argv[argc++] = "1000";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1000);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test29(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "-k";
	argv[argc++] = "1024";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	d.k = 1000;
	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test30(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "-sw";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 1);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test31(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "-sw";
	argv[argc++] = "0";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 1);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test32(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "-sw";
	argv[argc++] = "1";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.screen_width == 1);
	assert(d.manual_width == 1);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test33(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "-dtw";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	d.display_twiddle = 0;
	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0); 
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test34(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "-ntw";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0); 
	assert(d.display_twiddle == 0);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test35(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "-dc";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	d.display_datacount = 0;
	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0); 
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test36(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "-nc";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0); 
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 0);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test37(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "-dth";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	d.display_throughput = 0;
	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0); 
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test38(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "-nth";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0); 
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 0);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test39(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "-dt";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	d.display_time = 0;
	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0); 
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test40(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "-nt";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0); 
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 0);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test41(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "-dp";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	d.display_percent = 0;
	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0); 
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test42(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "-np";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0); 
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 0);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test43(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "-db";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	d.display_bar = 0;
	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0); 
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test44(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "-nb";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0); 
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 0);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test45(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "-ds";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	d.display_summary = 0;
	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0); 
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test46(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "-ns";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0); 
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 0);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test47(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "-da";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	d.display_twiddle = 0;
	d.display_datacount = 0;
	d.display_throughput = 0;
	d.display_time = 0;
	d.display_percent = 0;
	d.display_bar = 0;
	d.display_summary = 0;
	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0); 
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test48(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "-dn";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0); 
	assert(d.display_twiddle == 0);
	assert(d.display_datacount == 0);
	assert(d.display_throughput == 0);
	assert(d.display_time == 0);
	assert(d.display_percent == 0);
	assert(d.display_bar == 0);
	assert(d.display_summary == 0);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test49(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "--in-file";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 1);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test50(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "--in-file";
	argv[argc++] = "/dev/null";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in != 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test51(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "--out-file";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 1);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test52(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "--out-file";
	argv[argc++] = "/dev/null";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out != 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test53(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "--size";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 1);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test54(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "--size";
	argv[argc++] = "/dev/null";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test55(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "--size";
	argv[argc++] = "1024.38002m";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 1074140304);
	assert(io.total_size_known == 1);
	assert(io.timeout == 250000);
}

void test56(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "--buffer-size";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 1);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test57(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "--buffer-size";
	argv[argc++] = "/dev/null";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test58(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "--buffer-size";
	argv[argc++] = "1024.38002m";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1074140304);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test59(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "--interval";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 1);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test60(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "--interval";
	argv[argc++] = "/dev/null";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test61(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "--interval";
	argv[argc++] = "1024.38002m";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test62(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "--interval";
	argv[argc++] = "1024.38002";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test63(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "--interval";
	argv[argc++] = "30";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 30);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test64(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "--timeout";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 1);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test65(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "--timeout";
	argv[argc++] = "/dev/null";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test66(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "--timeout";
	argv[argc++] = "1024.38002m";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test67(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "--timeout";
	argv[argc++] = "1024.38002";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test68(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "--timeout";
	argv[argc++] = "30";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 30);
}

void test69(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "--kilo";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 1);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test70(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "--kilo";
	argv[argc++] = "10";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 1);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test71(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "--kilo";
	argv[argc++] = "1000";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1000);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test72(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "--kilo";
	argv[argc++] = "1024";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	d.k = 1000;
	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test73(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "--screen-width";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 1);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test74(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "--screen-width";
	argv[argc++] = "0";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 1);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test75(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "--screen-width";
	argv[argc++] = "1";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.screen_width == 1);
	assert(d.manual_width == 1);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test76(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "--display-twiddle";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	d.display_twiddle = 0;
	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0); 
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test77(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "--no-twiddle";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0); 
	assert(d.display_twiddle == 0);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test78(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "--display-count";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	d.display_datacount = 0;
	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0); 
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test79(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "--no-count";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0); 
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 0);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test80(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "--display-throughput";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	d.display_throughput = 0;
	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0); 
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test81(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "--no-throughput";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0); 
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 0);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test82(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "--display-time";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	d.display_time = 0;
	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0); 
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test83(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "--no-time";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0); 
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 0);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test84(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "--display-percent";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	d.display_percent = 0;
	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0); 
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test85(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "--no-percent";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0); 
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 0);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test86(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "--display-bar";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	d.display_bar = 0;
	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0); 
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test87(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "--no-bar";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0); 
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 0);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test88(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "--display-summary";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	d.display_summary = 0;
	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0); 
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test89(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "--no-summary";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0); 
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 0);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test90(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "--display-all";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	d.display_twiddle = 0;
	d.display_datacount = 0;
	d.display_throughput = 0;
	d.display_time = 0;
	d.display_percent = 0;
	d.display_bar = 0;
	d.display_summary = 0;
	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0); 
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test91(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "--display-none";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0); 
	assert(d.display_twiddle == 0);
	assert(d.display_datacount == 0);
	assert(d.display_throughput == 0);
	assert(d.display_time == 0);
	assert(d.display_percent == 0);
	assert(d.display_bar == 0);
	assert(d.display_summary == 0);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test92(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "-sw-1";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0); 
	assert(d.screen_width_minus_one == 1);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test93(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "--screen-width-minus-one";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0); 
	assert(d.screen_width_minus_one == 1);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test94(FILE *out)
{
	unlink("./test-rcfile.txt");

	clear_errno();
	ioInit();
	displayInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	clear_errno();
}

void test95(FILE *out)
{
	FILE *tmp_rcfile = 0;
	
	clear_errno();
	ioInit();
	displayInit();

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fclose(tmp_rcfile);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(unlink("./test-rcfile.txt") == 0);
}

void test96(FILE *out)
{
	FILE *tmp_rcfile = 0;
	
	clear_errno();
	ioInit();
	displayInit();

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "buffer");
	fclose(tmp_rcfile);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(test_parse_rc(out,1));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(unlink("./test-rcfile.txt") == 0);
}

void test97(FILE *out)
{
	FILE *tmp_rcfile = 0;
	
	clear_errno();
	ioInit();
	displayInit();

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "buffer:");
	fclose(tmp_rcfile);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(test_parse_rc(out,1));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(unlink("./test-rcfile.txt") == 0);
}

void test98(FILE *out)
{
	FILE *tmp_rcfile = 0;
	
	clear_errno();
	ioInit();
	displayInit();

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "buffer: ksjdhfkjh");
	fclose(tmp_rcfile);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(test_parse_rc(out,1));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(unlink("./test-rcfile.txt") == 0);
}

void test99(FILE *out)
{
	FILE *tmp_rcfile = 0;
	
	clear_errno();
	ioInit();
	displayInit();

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "buffer-size: ksjdhfkjh");
	fclose(tmp_rcfile);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(test_parse_rc(out,1));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(unlink("./test-rcfile.txt") == 0);
}

void test100(FILE *out)
{
	FILE *tmp_rcfile = 0;
	
	clear_errno();
	ioInit();
	displayInit();

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "buffer-size: ");
	fclose(tmp_rcfile);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(test_parse_rc(out,1));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(unlink("./test-rcfile.txt") == 0);
}

void test101(FILE *out)
{
	FILE *tmp_rcfile = 0;
	
	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "buffer-size: m");
	fclose(tmp_rcfile);

	clear_errno();
	ioInit();
	displayInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(test_parse_rc(out,1));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(unlink("./test-rcfile.txt") == 0);
}

void test102(FILE *out)
{
	FILE *tmp_rcfile = 0;
	
	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "buffer-size: .m");
	fclose(tmp_rcfile);

	clear_errno();
	ioInit();
	displayInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(test_parse_rc(out,1));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(unlink("./test-rcfile.txt") == 0);
}

void test103(FILE *out)
{
	FILE *tmp_rcfile = 0;
	
	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "buffer-size: 1m1");
	fclose(tmp_rcfile);

	clear_errno();
	ioInit();
	displayInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(test_parse_rc(out,1));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(unlink("./test-rcfile.txt") == 0);
}

void test104(FILE *out)
{
	FILE *tmp_rcfile = 0;
	
	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "buffer-size: .0m");
	fclose(tmp_rcfile);

	clear_errno();
	ioInit();
	displayInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(test_parse_rc(out,1));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(unlink("./test-rcfile.txt") == 0);
}

void test105(FILE *out)
{
	FILE *tmp_rcfile = 0;
	
	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "buffer-size: .1m");
	fclose(tmp_rcfile);

	clear_errno();
	ioInit();
	displayInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 104858);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(unlink("./test-rcfile.txt") == 0);
}

void test106(FILE *out)
{
	FILE *tmp_rcfile = 0;
	
	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "buffer-size: .10m");
	fclose(tmp_rcfile);

	clear_errno();
	ioInit();
	displayInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 104858);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(unlink("./test-rcfile.txt") == 0);
}

void test107(FILE *out)
{
	FILE *tmp_rcfile = 0;
	
	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "buffer-size: 1024.38m");
	fclose(tmp_rcfile);

	clear_errno();
	ioInit();
	displayInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1074140283);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(unlink("./test-rcfile.txt") == 0);
}

void test108(FILE *out)
{
	FILE *tmp_rcfile = 0;
	
	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "buffer-size: 1024.380m");
	fclose(tmp_rcfile);

	clear_errno();
	ioInit();
	displayInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1074140283);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(unlink("./test-rcfile.txt") == 0);
}

void test109(FILE *out)
{
	FILE *tmp_rcfile = 0;
	
	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "buffer-size: 1024.38002m");
	fclose(tmp_rcfile);

	clear_errno();
	ioInit();
	displayInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1074140304);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(unlink("./test-rcfile.txt") == 0);
}

void test110(FILE *out)
{
	uint64 e;
	FILE *tmp_rcfile = 0;
	
	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "buffer-size: 18446744073709551615");
	fclose(tmp_rcfile);

	clear_errno();
	ioInit();
	displayInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

#if SIZEOF_SIZE_T == 8
	assert(test_parse_rc(out,0));
#else
	assert(test_parse_rc(out,1));
#endif

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
#if SIZEOF_SIZE_T == 8
	e = 18;
	e *= 1000;
	e += 446;
	e *= 1000;
	e += 744;
	e *= 1000;
	e += 73;
	e *= 1000;
	e += 709;
	e *= 1000;
	e += 551;
	e *= 1000;
	e += 615;
	assert(io.buffer_size == e);
#else
	assert(io.buffer_size == 1024);
#endif
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(unlink("./test-rcfile.txt") == 0);
}

void test111(FILE *out)
{
	uint64 e;
	FILE *tmp_rcfile = 0;
	
	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "buffer-size: 4294967295");
	fclose(tmp_rcfile);

	clear_errno();
	ioInit();
	displayInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	e = 4;
	e *= 1000;
	e += 294;
	e *= 1000;
	e += 967;
	e *= 1000;
	e += 295;
	assert(io.buffer_size == e);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(unlink("./test-rcfile.txt") == 0);
}

void test112(FILE *out)
{
	FILE *tmp_rcfile = 0;
	
	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "buffer-size: 3.019933546896392720878322259136212624584717607973421926910299003322259136212624g");
	fclose(tmp_rcfile);

	clear_errno();
	ioInit();
	displayInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(test_parse_rc(out,1));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(unlink("./test-rcfile.txt") == 0);
}

void test113(FILE *out)
{
	uint64 e;
	FILE *tmp_rcfile = 0;
	
	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "buffer-size: 3.0199335468963927208783222591362126245847176079734219269102990033222591362126g");
	fclose(tmp_rcfile);

	clear_errno();
	ioInit();
	displayInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	e = 3;
	e *= 1000;
	e += 242;
	e *= 1000;
	e += 628;
	e *= 1000;
	e += 954;
	assert(io.buffer_size == e);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(unlink("./test-rcfile.txt") == 0);
}

void test114(FILE *out)
{
	FILE *tmp_rcfile = 0;
	
	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "interval: 5");
	fclose(tmp_rcfile);

	clear_errno();
	ioInit();
	displayInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 5);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(unlink("./test-rcfile.txt") == 0);
}

void test115(FILE *out)
{
	FILE *tmp_rcfile = 0;
	
	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "interval: /dev/null");
	fclose(tmp_rcfile);

	clear_errno();
	ioInit();
	displayInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(test_parse_rc(out,1));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(unlink("./test-rcfile.txt") == 0);
}

void test116(FILE *out)
{
	FILE *tmp_rcfile = 0;
	
	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "interval: 1024.38002m");
	fclose(tmp_rcfile);

	clear_errno();
	ioInit();
	displayInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(test_parse_rc(out,1));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(unlink("./test-rcfile.txt") == 0);
}

void test117(FILE *out)
{
	FILE *tmp_rcfile = 0;
	
	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "interval: 1024.38002");
	fclose(tmp_rcfile);

	clear_errno();
	ioInit();
	displayInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(test_parse_rc(out,1));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(unlink("./test-rcfile.txt") == 0);
}

void test118(FILE *out)
{
	FILE *tmp_rcfile = 0;
	
	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "timeout: 5");
	fclose(tmp_rcfile);

	clear_errno();
	ioInit();
	displayInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 5);

	assert(unlink("./test-rcfile.txt") == 0);
}

void test119(FILE *out)
{
	FILE *tmp_rcfile = 0;
	
	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "timeout: /dev/null");
	fclose(tmp_rcfile);

	clear_errno();
	ioInit();
	displayInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(test_parse_rc(out,1));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(unlink("./test-rcfile.txt") == 0);
}

void test120(FILE *out)
{
	FILE *tmp_rcfile = 0;
	
	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "timeout: 1024.38002m");
	fclose(tmp_rcfile);

	clear_errno();
	ioInit();
	displayInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(test_parse_rc(out,1));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(unlink("./test-rcfile.txt") == 0);
}

void test121(FILE *out)
{
	FILE *tmp_rcfile = 0;
	
	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "timeout: 1024.38002");
	fclose(tmp_rcfile);

	clear_errno();
	ioInit();
	displayInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(test_parse_rc(out,1));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(unlink("./test-rcfile.txt") == 0);
}

void test122(FILE *out)
{
	FILE *tmp_rcfile = 0;
	
	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "kilobyte: 10");
	fclose(tmp_rcfile);

	clear_errno();
	ioInit();
	displayInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(test_parse_rc(out,1));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(unlink("./test-rcfile.txt") == 0);
}

void test123(FILE *out)
{
	FILE *tmp_rcfile = 0;
	
	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "kilobyte: 1000");
	fclose(tmp_rcfile);

	clear_errno();
	ioInit();
	displayInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1000);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(unlink("./test-rcfile.txt") == 0);
}

void test124(FILE *out)
{
	FILE *tmp_rcfile = 0;
	
	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "kilobyte: 1024");
	fclose(tmp_rcfile);

	clear_errno();
	ioInit();
	displayInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	d.k = 1000;
	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(unlink("./test-rcfile.txt") == 0);
}

void test125(FILE *out)
{
	FILE *tmp_rcfile = 0;
	
	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "screen-width: 0");
	fclose(tmp_rcfile);

	clear_errno();
	ioInit();
	displayInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(test_parse_rc(out,1));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(unlink("./test-rcfile.txt") == 0);
}

void test126(FILE *out)
{
	FILE *tmp_rcfile = 0;
	
	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "screen-width: 1");
	fclose(tmp_rcfile);

	clear_errno();
	ioInit();
	displayInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(test_parse_rc(out,0));
	assert(d.screen_width == 1);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 1);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(unlink("./test-rcfile.txt") == 0);
}

void test127(FILE *out)
{
	FILE *tmp_rcfile = 0;
	
	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "display-twiddle: Sjkhg");
	fclose(tmp_rcfile);

	clear_errno();
	ioInit();
	displayInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(test_parse_rc(out,1));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "display-twiddle: no");
	fclose(tmp_rcfile);

	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 0);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "display-twiddle: yes");
	fclose(tmp_rcfile);

	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "display-twiddle: n");
	fclose(tmp_rcfile);

	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 0);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "display-twiddle: y");
	fclose(tmp_rcfile);

	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "display-twiddle: false");
	fclose(tmp_rcfile);

	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 0);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "display-twiddle: true");
	fclose(tmp_rcfile);

	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "display-twiddle: f");
	fclose(tmp_rcfile);

	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 0);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "display-twiddle: t");
	fclose(tmp_rcfile);

	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "display-twiddle: 0");
	fclose(tmp_rcfile);

	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 0);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "display-twiddle: 1");
	fclose(tmp_rcfile);

	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "display-twiddle: off");
	fclose(tmp_rcfile);

	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 0);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "display-twiddle: on");
	fclose(tmp_rcfile);

	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(unlink("./test-rcfile.txt") == 0);
}

void test128(FILE *out)
{
	FILE *tmp_rcfile = 0;
	
	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "display-count: Sjkhg");
	fclose(tmp_rcfile);

	clear_errno();
	ioInit();
	displayInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(test_parse_rc(out,1));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "display-count: no");
	fclose(tmp_rcfile);

	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 0);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "display-count: yes");
	fclose(tmp_rcfile);

	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "display-count: n");
	fclose(tmp_rcfile);

	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 0);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "display-count: y");
	fclose(tmp_rcfile);

	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "display-count: false");
	fclose(tmp_rcfile);

	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 0);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "display-count: true");
	fclose(tmp_rcfile);

	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "display-count: f");
	fclose(tmp_rcfile);

	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 0);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "display-count: t");
	fclose(tmp_rcfile);

	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "display-count: 0");
	fclose(tmp_rcfile);

	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 0);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "display-count: 1");
	fclose(tmp_rcfile);

	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "display-count: off");
	fclose(tmp_rcfile);

	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 0);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "display-count: on");
	fclose(tmp_rcfile);

	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(unlink("./test-rcfile.txt") == 0);
}

void test129(FILE *out)
{
	FILE *tmp_rcfile = 0;
	
	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "display-throughput: Sjkhg");
	fclose(tmp_rcfile);

	clear_errno();
	ioInit();
	displayInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(test_parse_rc(out,1));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "display-throughput: no");
	fclose(tmp_rcfile);

	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 0);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "display-throughput: yes");
	fclose(tmp_rcfile);

	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "display-throughput: n");
	fclose(tmp_rcfile);

	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 0);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "display-throughput: y");
	fclose(tmp_rcfile);

	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "display-throughput: false");
	fclose(tmp_rcfile);

	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 0);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "display-throughput: true");
	fclose(tmp_rcfile);

	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "display-throughput: f");
	fclose(tmp_rcfile);

	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 0);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "display-throughput: t");
	fclose(tmp_rcfile);

	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "display-throughput: 0");
	fclose(tmp_rcfile);

	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 0);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "display-throughput: 1");
	fclose(tmp_rcfile);

	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "display-throughput: off");
	fclose(tmp_rcfile);

	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 0);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "display-throughput: on");
	fclose(tmp_rcfile);

	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(unlink("./test-rcfile.txt") == 0);
}

void test130(FILE *out)
{
	FILE *tmp_rcfile = 0;
	
	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "display-time: Sjkhg");
	fclose(tmp_rcfile);

	clear_errno();
	ioInit();
	displayInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(test_parse_rc(out,1));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "display-time: no");
	fclose(tmp_rcfile);

	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 0);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "display-time: yes");
	fclose(tmp_rcfile);

	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "display-time: n");
	fclose(tmp_rcfile);

	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 0);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "display-time: y");
	fclose(tmp_rcfile);

	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "display-time: false");
	fclose(tmp_rcfile);

	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 0);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "display-time: true");
	fclose(tmp_rcfile);

	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "display-time: f");
	fclose(tmp_rcfile);

	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 0);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "display-time: t");
	fclose(tmp_rcfile);

	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "display-time: 0");
	fclose(tmp_rcfile);

	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 0);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "display-time: 1");
	fclose(tmp_rcfile);

	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "display-time: off");
	fclose(tmp_rcfile);

	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 0);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "display-time: on");
	fclose(tmp_rcfile);

	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(unlink("./test-rcfile.txt") == 0);
}

void test131(FILE *out)
{
	FILE *tmp_rcfile = 0;
	
	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "display-percent: Sjkhg");
	fclose(tmp_rcfile);

	clear_errno();
	ioInit();
	displayInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(test_parse_rc(out,1));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "display-percent: no");
	fclose(tmp_rcfile);

	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 0);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "display-percent: yes");
	fclose(tmp_rcfile);

	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "display-percent: n");
	fclose(tmp_rcfile);

	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 0);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "display-percent: y");
	fclose(tmp_rcfile);

	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "display-percent: false");
	fclose(tmp_rcfile);

	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 0);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "display-percent: true");
	fclose(tmp_rcfile);

	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "display-percent: f");
	fclose(tmp_rcfile);

	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 0);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "display-percent: t");
	fclose(tmp_rcfile);

	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "display-percent: 0");
	fclose(tmp_rcfile);

	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 0);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "display-percent: 1");
	fclose(tmp_rcfile);

	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "display-percent: off");
	fclose(tmp_rcfile);

	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 0);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "display-percent: on");
	fclose(tmp_rcfile);

	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(unlink("./test-rcfile.txt") == 0);
}

void test132(FILE *out)
{
	FILE *tmp_rcfile = 0;
	
	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "display-bar: Sjkhg");
	fclose(tmp_rcfile);

	clear_errno();
	ioInit();
	displayInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(test_parse_rc(out,1));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "display-bar: no");
	fclose(tmp_rcfile);

	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 0);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "display-bar: yes");
	fclose(tmp_rcfile);

	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "display-bar: n");
	fclose(tmp_rcfile);

	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 0);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "display-bar: y");
	fclose(tmp_rcfile);

	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "display-bar: false");
	fclose(tmp_rcfile);

	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 0);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "display-bar: true");
	fclose(tmp_rcfile);

	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "display-bar: f");
	fclose(tmp_rcfile);

	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 0);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "display-bar: t");
	fclose(tmp_rcfile);

	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "display-bar: 0");
	fclose(tmp_rcfile);

	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 0);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "display-bar: 1");
	fclose(tmp_rcfile);

	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "display-bar: off");
	fclose(tmp_rcfile);

	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 0);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "display-bar: on");
	fclose(tmp_rcfile);

	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(unlink("./test-rcfile.txt") == 0);
}

void test133(FILE *out)
{
	FILE *tmp_rcfile = 0;
	
	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "display-summary: Sjkhg");
	fclose(tmp_rcfile);

	clear_errno();
	ioInit();
	displayInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(test_parse_rc(out,1));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "display-summary: no");
	fclose(tmp_rcfile);

	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 0);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "display-summary: yes");
	fclose(tmp_rcfile);

	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "display-summary: n");
	fclose(tmp_rcfile);

	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 0);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "display-summary: y");
	fclose(tmp_rcfile);

	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "display-summary: false");
	fclose(tmp_rcfile);

	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 0);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "display-summary: true");
	fclose(tmp_rcfile);

	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "display-summary: f");
	fclose(tmp_rcfile);

	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 0);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "display-summary: t");
	fclose(tmp_rcfile);

	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "display-summary: 0");
	fclose(tmp_rcfile);

	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 0);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "display-summary: 1");
	fclose(tmp_rcfile);

	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "display-summary: off");
	fclose(tmp_rcfile);

	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 0);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "display-summary: on");
	fclose(tmp_rcfile);

	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(unlink("./test-rcfile.txt") == 0);
}

void test134(FILE *out)
{
	FILE *tmp_rcfile = 0;
	
	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "screen-width-minus-one: Sjkhg");
	fclose(tmp_rcfile);

	clear_errno();
	ioInit();
	displayInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(test_parse_rc(out,1));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "screen-width-minus-one: no");
	fclose(tmp_rcfile);

	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "screen-width-minus-one: yes");
	fclose(tmp_rcfile);

	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 1);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "screen-width-minus-one: n");
	fclose(tmp_rcfile);

	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "screen-width-minus-one: y");
	fclose(tmp_rcfile);

	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 1);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "screen-width-minus-one: false");
	fclose(tmp_rcfile);

	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "screen-width-minus-one: true");
	fclose(tmp_rcfile);

	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 1);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "screen-width-minus-one: f");
	fclose(tmp_rcfile);

	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "screen-width-minus-one: t");
	fclose(tmp_rcfile);

	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 1);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "screen-width-minus-one: 0");
	fclose(tmp_rcfile);

	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "screen-width-minus-one: 1");
	fclose(tmp_rcfile);

	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 1);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "screen-width-minus-one: off");
	fclose(tmp_rcfile);

	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "screen-width-minus-one: on");
	fclose(tmp_rcfile);

	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 1);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(unlink("./test-rcfile.txt") == 0);
}

void test135(FILE *out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "-dan";

	clear_errno();
	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 1);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test136(FILE *out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "-nan";

	clear_errno();
	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	d.display_ansi = 1;
	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test137(FILE *out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "--display-ansi";

	clear_errno();
	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 1);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test138(FILE *out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "--no-ansi";

	clear_errno();
	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	d.display_ansi = 1;
	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test139(FILE *out)
{
	FILE *tmp_rcfile = 0;
	
	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "display-ansi: Sjkhg");
	fclose(tmp_rcfile);

	clear_errno();
	ioInit();
	displayInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(test_parse_rc(out,1));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "display-ansi: no");
	fclose(tmp_rcfile);

	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "display-ansi: yes");
	fclose(tmp_rcfile);

	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 1);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "display-ansi: n");
	fclose(tmp_rcfile);

	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "display-ansi: y");
	fclose(tmp_rcfile);

	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 1);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "display-ansi: false");
	fclose(tmp_rcfile);

	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "display-ansi: true");
	fclose(tmp_rcfile);

	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 1);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "display-ansi: f");
	fclose(tmp_rcfile);

	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "display-ansi: t");
	fclose(tmp_rcfile);

	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 1);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "display-ansi: 0");
	fclose(tmp_rcfile);

	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "display-ansi: 1");
	fclose(tmp_rcfile);

	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 1);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "display-ansi: off");
	fclose(tmp_rcfile);

	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "display-ansi: on");
	fclose(tmp_rcfile);

	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 1);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(unlink("./test-rcfile.txt") == 0);
}

void test140(FILE *out)
{
	int argc = 0;
	char *argv[256] = { 0 };
	FILE *tmp_rcfile = 0;

	unlink("./test-rcfile.txt");

	for (argc = 0; argc < 256; argc++)
		argv[argc] = 0;
	argc = 0;
	argv[argc++] = "ProgramName";
	argv[argc++] = "-twfg";

	clear_errno();
	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	for (argc = 0; argc < 256; argc++)
		argv[argc] = 0;
	argc = 0;
	argv[argc++] = "ProgramName";
	argv[argc++] = "-twfg";
	argv[argc++] = "/dev/null";

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	for (argc = 0; argc < 256; argc++)
		argv[argc] = 0;
	argc = 0;
	argv[argc++] = "ProgramName";
	argv[argc++] = "-twfg";
	argv[argc++] = "black";

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert((d.twiddle_fg_color != 0) && (strcmp(d.twiddle_fg_color, "[30m") == 0));
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	for (argc = 0; argc < 256; argc++)
		argv[argc] = 0;
	argc = 0;
	argv[argc++] = "ProgramName";
	argv[argc++] = "-twfg";
	argv[argc++] = "red";

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert((d.twiddle_fg_color != 0) && (strcmp(d.twiddle_fg_color, "[31m") == 0));
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	for (argc = 0; argc < 256; argc++)
		argv[argc] = 0;
	argc = 0;
	argv[argc++] = "ProgramName";
	argv[argc++] = "-twfg";
	argv[argc++] = "green";

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert((d.twiddle_fg_color != 0) && (strcmp(d.twiddle_fg_color, "[32m") == 0));
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	for (argc = 0; argc < 256; argc++)
		argv[argc] = 0;
	argc = 0;
	argv[argc++] = "ProgramName";
	argv[argc++] = "-twfg";
	argv[argc++] = "yellow";

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert((d.twiddle_fg_color != 0) && (strcmp(d.twiddle_fg_color, "[33m") == 0));
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	for (argc = 0; argc < 256; argc++)
		argv[argc] = 0;
	argc = 0;
	argv[argc++] = "ProgramName";
	argv[argc++] = "-twfg";
	argv[argc++] = "blue";

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert((d.twiddle_fg_color != 0) && (strcmp(d.twiddle_fg_color, "[34m") == 0));
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	for (argc = 0; argc < 256; argc++)
		argv[argc] = 0;
	argc = 0;
	argv[argc++] = "ProgramName";
	argv[argc++] = "-twfg";
	argv[argc++] = "magenta";

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert((d.twiddle_fg_color != 0) && (strcmp(d.twiddle_fg_color, "[35m") == 0));
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	for (argc = 0; argc < 256; argc++)
		argv[argc] = 0;
	argc = 0;
	argv[argc++] = "ProgramName";
	argv[argc++] = "-twfg";
	argv[argc++] = "cyan";

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert((d.twiddle_fg_color != 0) && (strcmp(d.twiddle_fg_color, "[36m") == 0));
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	for (argc = 0; argc < 256; argc++)
		argv[argc] = 0;
	argc = 0;
	argv[argc++] = "ProgramName";
	argv[argc++] = "-twfg";
	argv[argc++] = "white";

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert((d.twiddle_fg_color != 0) && (strcmp(d.twiddle_fg_color, "[37m") == 0));
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	for (argc = 0; argc < 256; argc++)
		argv[argc] = 0;
	argc = 0;
	argv[argc++] = "ProgramName";
	argv[argc++] = "-twfg";
	argv[argc++] = "normal";

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	for (argc = 0; argc < 256; argc++)
		argv[argc] = 0;
	argc = 0;
	argv[argc++] = "ProgramName";
	argv[argc++] = "-twbg";

	clear_errno();
	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	for (argc = 0; argc < 256; argc++)
		argv[argc] = 0;
	argc = 0;
	argv[argc++] = "ProgramName";
	argv[argc++] = "-twbg";
	argv[argc++] = "/dev/null";

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	for (argc = 0; argc < 256; argc++)
		argv[argc] = 0;
	argc = 0;
	argv[argc++] = "ProgramName";
	argv[argc++] = "-twbg";
	argv[argc++] = "black";

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert((d.twiddle_bg_color != 0) && (strcmp(d.twiddle_bg_color, "[40m") == 0));
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	for (argc = 0; argc < 256; argc++)
		argv[argc] = 0;
	argc = 0;
	argv[argc++] = "ProgramName";
	argv[argc++] = "-twbg";
	argv[argc++] = "red";

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert((d.twiddle_bg_color != 0) && (strcmp(d.twiddle_bg_color, "[41m") == 0));
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	for (argc = 0; argc < 256; argc++)
		argv[argc] = 0;
	argc = 0;
	argv[argc++] = "ProgramName";
	argv[argc++] = "-twbg";
	argv[argc++] = "green";

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert((d.twiddle_bg_color != 0) && (strcmp(d.twiddle_bg_color, "[42m") == 0));
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	for (argc = 0; argc < 256; argc++)
		argv[argc] = 0;
	argc = 0;
	argv[argc++] = "ProgramName";
	argv[argc++] = "-twbg";
	argv[argc++] = "yellow";

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert((d.twiddle_bg_color != 0) && (strcmp(d.twiddle_bg_color, "[43m") == 0));
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	for (argc = 0; argc < 256; argc++)
		argv[argc] = 0;
	argc = 0;
	argv[argc++] = "ProgramName";
	argv[argc++] = "-twbg";
	argv[argc++] = "blue";

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert((d.twiddle_bg_color != 0) && (strcmp(d.twiddle_bg_color, "[44m") == 0));
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	for (argc = 0; argc < 256; argc++)
		argv[argc] = 0;
	argc = 0;
	argv[argc++] = "ProgramName";
	argv[argc++] = "-twbg";
	argv[argc++] = "magenta";

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert((d.twiddle_bg_color != 0) && (strcmp(d.twiddle_bg_color, "[45m") == 0));
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	for (argc = 0; argc < 256; argc++)
		argv[argc] = 0;
	argc = 0;
	argv[argc++] = "ProgramName";
	argv[argc++] = "-twbg";
	argv[argc++] = "cyan";

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert((d.twiddle_bg_color != 0) && (strcmp(d.twiddle_bg_color, "[46m") == 0));
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	for (argc = 0; argc < 256; argc++)
		argv[argc] = 0;
	argc = 0;
	argv[argc++] = "ProgramName";
	argv[argc++] = "-twbg";
	argv[argc++] = "white";

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert((d.twiddle_bg_color != 0) && (strcmp(d.twiddle_bg_color, "[47m") == 0));
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	for (argc = 0; argc < 256; argc++)
		argv[argc] = 0;
	argc = 0;
	argv[argc++] = "ProgramName";
	argv[argc++] = "-twbg";
	argv[argc++] = "normal";

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	for (argc = 0; argc < 256; argc++)
		argv[argc] = 0;
	argc = 0;
	argv[argc++] = "ProgramName";
	argv[argc++] = "-twb";

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 1);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	for (argc = 0; argc < 256; argc++)
		argv[argc] = 0;
	argc = 0;
	argv[argc++] = "ProgramName";
	argv[argc++] = "-twn";

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(test_parse_rc(out, 0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fclose(tmp_rcfile);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "twiddle-foreground: kjshdfkjh");
	fclose(tmp_rcfile);

	clear_errno();
	assert(test_parse_rc(out,1));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "twiddle-foreground: black");
	fclose(tmp_rcfile);

	clear_errno();
	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert((d.twiddle_fg_color != 0) && (strcmp(d.twiddle_fg_color, "[30m") == 0));
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "twiddle-foreground: red");
	fclose(tmp_rcfile);

	clear_errno();
	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert((d.twiddle_fg_color != 0) && (strcmp(d.twiddle_fg_color, "[31m") == 0));
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "twiddle-foreground: green");
	fclose(tmp_rcfile);

	clear_errno();
	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert((d.twiddle_fg_color != 0) && (strcmp(d.twiddle_fg_color, "[32m") == 0));
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "twiddle-foreground: yellow");
	fclose(tmp_rcfile);

	clear_errno();
	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert((d.twiddle_fg_color != 0) && (strcmp(d.twiddle_fg_color, "[33m") == 0));
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "twiddle-foreground: blue");
	fclose(tmp_rcfile);

	clear_errno();
	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert((d.twiddle_fg_color != 0) && (strcmp(d.twiddle_fg_color, "[34m") == 0));
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "twiddle-foreground: magenta");
	fclose(tmp_rcfile);

	clear_errno();
	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert((d.twiddle_fg_color != 0) && (strcmp(d.twiddle_fg_color, "[35m") == 0));
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "twiddle-foreground: cyan");
	fclose(tmp_rcfile);

	clear_errno();
	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert((d.twiddle_fg_color != 0) && (strcmp(d.twiddle_fg_color, "[36m") == 0));
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "twiddle-foreground: white");
	fclose(tmp_rcfile);

	clear_errno();
	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert((d.twiddle_fg_color != 0) && (strcmp(d.twiddle_fg_color, "[37m") == 0));
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "twiddle-foreground: normal");
	fclose(tmp_rcfile);

	clear_errno();
	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "twiddle-background: kjshdfkjh");
	fclose(tmp_rcfile);

	clear_errno();
	assert(test_parse_rc(out,1));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "twiddle-background: black");
	fclose(tmp_rcfile);

	clear_errno();
	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert((d.twiddle_bg_color != 0) && (strcmp(d.twiddle_bg_color, "[40m") == 0));
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "twiddle-background: red");
	fclose(tmp_rcfile);

	clear_errno();
	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert((d.twiddle_bg_color != 0) && (strcmp(d.twiddle_bg_color, "[41m") == 0));
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "twiddle-background: green");
	fclose(tmp_rcfile);

	clear_errno();
	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert((d.twiddle_bg_color != 0) && (strcmp(d.twiddle_bg_color, "[42m") == 0));
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "twiddle-background: yellow");
	fclose(tmp_rcfile);

	clear_errno();
	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert((d.twiddle_bg_color != 0) && (strcmp(d.twiddle_bg_color, "[43m") == 0));
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "twiddle-background: blue");
	fclose(tmp_rcfile);

	clear_errno();
	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert((d.twiddle_bg_color != 0) && (strcmp(d.twiddle_bg_color, "[44m") == 0));
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "twiddle-background: magenta");
	fclose(tmp_rcfile);

	clear_errno();
	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert((d.twiddle_bg_color != 0) && (strcmp(d.twiddle_bg_color, "[45m") == 0));
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "twiddle-background: cyan");
	fclose(tmp_rcfile);

	clear_errno();
	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert((d.twiddle_bg_color != 0) && (strcmp(d.twiddle_bg_color, "[46m") == 0));
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "twiddle-background: white");
	fclose(tmp_rcfile);

	clear_errno();
	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert((d.twiddle_bg_color != 0) && (strcmp(d.twiddle_bg_color, "[47m") == 0));
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "twiddle-background: normal");
	fclose(tmp_rcfile);

	clear_errno();
	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "twiddle-bold: Sjkhg");
	fclose(tmp_rcfile);

	clear_errno();
	assert(test_parse_rc(out,1));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "twiddle-bold: no");
	fclose(tmp_rcfile);

	clear_errno();
	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "twiddle-bold: yes");
	fclose(tmp_rcfile);

	clear_errno();
	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 1);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "twiddle-bold: n");
	fclose(tmp_rcfile);

	clear_errno();
	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "twiddle-bold: y");
	fclose(tmp_rcfile);

	clear_errno();
	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 1);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "twiddle-bold: false");
	fclose(tmp_rcfile);

	clear_errno();
	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "twiddle-bold: true");
	fclose(tmp_rcfile);

	clear_errno();
	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 1);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "twiddle-bold: f");
	fclose(tmp_rcfile);

	clear_errno();
	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "twiddle-bold: t");
	fclose(tmp_rcfile);

	clear_errno();
	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 1);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "twiddle-bold: 0");
	fclose(tmp_rcfile);

	clear_errno();
	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "twiddle-bold: 1");
	fclose(tmp_rcfile);

	clear_errno();
	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 1);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "twiddle-bold: off");
	fclose(tmp_rcfile);

	clear_errno();
	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "twiddle-bold: on");
	fclose(tmp_rcfile);

	clear_errno();
	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 1);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(unlink("./test-rcfile.txt") == 0);
}

void test141(FILE *out)
{
	int argc = 0;
	char *argv[256] = { 0 };
	FILE *tmp_rcfile = 0;

	unlink("./test-rcfile.txt");

	for (argc = 0; argc < 256; argc++)
		argv[argc] = 0;
	argc = 0;
	argv[argc++] = "ProgramName";
	argv[argc++] = "-cfg";

	clear_errno();
	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	for (argc = 0; argc < 256; argc++)
		argv[argc] = 0;
	argc = 0;
	argv[argc++] = "ProgramName";
	argv[argc++] = "-cfg";
	argv[argc++] = "/dev/null";

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	for (argc = 0; argc < 256; argc++)
		argv[argc] = 0;
	argc = 0;
	argv[argc++] = "ProgramName";
	argv[argc++] = "-cfg";
	argv[argc++] = "black";

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert((d.datacount_fg_color != 0) && (strcmp(d.datacount_fg_color, "[30m") == 0));
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	for (argc = 0; argc < 256; argc++)
		argv[argc] = 0;
	argc = 0;
	argv[argc++] = "ProgramName";
	argv[argc++] = "-cfg";
	argv[argc++] = "red";

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert((d.datacount_fg_color != 0) && (strcmp(d.datacount_fg_color, "[31m") == 0));
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	for (argc = 0; argc < 256; argc++)
		argv[argc] = 0;
	argc = 0;
	argv[argc++] = "ProgramName";
	argv[argc++] = "-cfg";
	argv[argc++] = "green";

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert((d.datacount_fg_color != 0) && (strcmp(d.datacount_fg_color, "[32m") == 0));
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	for (argc = 0; argc < 256; argc++)
		argv[argc] = 0;
	argc = 0;
	argv[argc++] = "ProgramName";
	argv[argc++] = "-cfg";
	argv[argc++] = "yellow";

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert((d.datacount_fg_color != 0) && (strcmp(d.datacount_fg_color, "[33m") == 0));
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	for (argc = 0; argc < 256; argc++)
		argv[argc] = 0;
	argc = 0;
	argv[argc++] = "ProgramName";
	argv[argc++] = "-cfg";
	argv[argc++] = "blue";

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert((d.datacount_fg_color != 0) && (strcmp(d.datacount_fg_color, "[34m") == 0));
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	for (argc = 0; argc < 256; argc++)
		argv[argc] = 0;
	argc = 0;
	argv[argc++] = "ProgramName";
	argv[argc++] = "-cfg";
	argv[argc++] = "magenta";

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert((d.datacount_fg_color != 0) && (strcmp(d.datacount_fg_color, "[35m") == 0));
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	for (argc = 0; argc < 256; argc++)
		argv[argc] = 0;
	argc = 0;
	argv[argc++] = "ProgramName";
	argv[argc++] = "-cfg";
	argv[argc++] = "cyan";

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert((d.datacount_fg_color != 0) && (strcmp(d.datacount_fg_color, "[36m") == 0));
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	for (argc = 0; argc < 256; argc++)
		argv[argc] = 0;
	argc = 0;
	argv[argc++] = "ProgramName";
	argv[argc++] = "-cfg";
	argv[argc++] = "white";

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert((d.datacount_fg_color != 0) && (strcmp(d.datacount_fg_color, "[37m") == 0));
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	for (argc = 0; argc < 256; argc++)
		argv[argc] = 0;
	argc = 0;
	argv[argc++] = "ProgramName";
	argv[argc++] = "-cfg";
	argv[argc++] = "normal";

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	for (argc = 0; argc < 256; argc++)
		argv[argc] = 0;
	argc = 0;
	argv[argc++] = "ProgramName";
	argv[argc++] = "-cbg";

	clear_errno();
	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	for (argc = 0; argc < 256; argc++)
		argv[argc] = 0;
	argc = 0;
	argv[argc++] = "ProgramName";
	argv[argc++] = "-cbg";
	argv[argc++] = "/dev/null";

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	for (argc = 0; argc < 256; argc++)
		argv[argc] = 0;
	argc = 0;
	argv[argc++] = "ProgramName";
	argv[argc++] = "-cbg";
	argv[argc++] = "black";

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert((d.datacount_bg_color != 0) && (strcmp(d.datacount_bg_color, "[40m") == 0));
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	for (argc = 0; argc < 256; argc++)
		argv[argc] = 0;
	argc = 0;
	argv[argc++] = "ProgramName";
	argv[argc++] = "-cbg";
	argv[argc++] = "red";

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert((d.datacount_bg_color != 0) && (strcmp(d.datacount_bg_color, "[41m") == 0));
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	for (argc = 0; argc < 256; argc++)
		argv[argc] = 0;
	argc = 0;
	argv[argc++] = "ProgramName";
	argv[argc++] = "-cbg";
	argv[argc++] = "green";

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert((d.datacount_bg_color != 0) && (strcmp(d.datacount_bg_color, "[42m") == 0));
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	for (argc = 0; argc < 256; argc++)
		argv[argc] = 0;
	argc = 0;
	argv[argc++] = "ProgramName";
	argv[argc++] = "-cbg";
	argv[argc++] = "yellow";

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert((d.datacount_bg_color != 0) && (strcmp(d.datacount_bg_color, "[43m") == 0));
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	for (argc = 0; argc < 256; argc++)
		argv[argc] = 0;
	argc = 0;
	argv[argc++] = "ProgramName";
	argv[argc++] = "-cbg";
	argv[argc++] = "blue";

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert((d.datacount_bg_color != 0) && (strcmp(d.datacount_bg_color, "[44m") == 0));
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	for (argc = 0; argc < 256; argc++)
		argv[argc] = 0;
	argc = 0;
	argv[argc++] = "ProgramName";
	argv[argc++] = "-cbg";
	argv[argc++] = "magenta";

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert((d.datacount_bg_color != 0) && (strcmp(d.datacount_bg_color, "[45m") == 0));
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	for (argc = 0; argc < 256; argc++)
		argv[argc] = 0;
	argc = 0;
	argv[argc++] = "ProgramName";
	argv[argc++] = "-cbg";
	argv[argc++] = "cyan";

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert((d.datacount_bg_color != 0) && (strcmp(d.datacount_bg_color, "[46m") == 0));
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	for (argc = 0; argc < 256; argc++)
		argv[argc] = 0;
	argc = 0;
	argv[argc++] = "ProgramName";
	argv[argc++] = "-cbg";
	argv[argc++] = "white";

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert((d.datacount_bg_color != 0) && (strcmp(d.datacount_bg_color, "[47m") == 0));
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	for (argc = 0; argc < 256; argc++)
		argv[argc] = 0;
	argc = 0;
	argv[argc++] = "ProgramName";
	argv[argc++] = "-cbg";
	argv[argc++] = "normal";

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	for (argc = 0; argc < 256; argc++)
		argv[argc] = 0;
	argc = 0;
	argv[argc++] = "ProgramName";
	argv[argc++] = "-cb";

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 1);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	for (argc = 0; argc < 256; argc++)
		argv[argc] = 0;
	argc = 0;
	argv[argc++] = "ProgramName";
	argv[argc++] = "-cn";

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(test_parse_rc(out, 0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fclose(tmp_rcfile);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "count-foreground: kjshdfkjh");
	fclose(tmp_rcfile);

	clear_errno();
	assert(test_parse_rc(out,1));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "count-foreground: black");
	fclose(tmp_rcfile);

	clear_errno();
	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert((d.datacount_fg_color != 0) && (strcmp(d.datacount_fg_color, "[30m") == 0));
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "count-foreground: red");
	fclose(tmp_rcfile);

	clear_errno();
	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert((d.datacount_fg_color != 0) && (strcmp(d.datacount_fg_color, "[31m") == 0));
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "count-foreground: green");
	fclose(tmp_rcfile);

	clear_errno();
	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert((d.datacount_fg_color != 0) && (strcmp(d.datacount_fg_color, "[32m") == 0));
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "count-foreground: yellow");
	fclose(tmp_rcfile);

	clear_errno();
	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert((d.datacount_fg_color != 0) && (strcmp(d.datacount_fg_color, "[33m") == 0));
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "count-foreground: blue");
	fclose(tmp_rcfile);

	clear_errno();
	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert((d.datacount_fg_color != 0) && (strcmp(d.datacount_fg_color, "[34m") == 0));
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "count-foreground: magenta");
	fclose(tmp_rcfile);

	clear_errno();
	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert((d.datacount_fg_color != 0) && (strcmp(d.datacount_fg_color, "[35m") == 0));
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "count-foreground: cyan");
	fclose(tmp_rcfile);

	clear_errno();
	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert((d.datacount_fg_color != 0) && (strcmp(d.datacount_fg_color, "[36m") == 0));
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "count-foreground: white");
	fclose(tmp_rcfile);

	clear_errno();
	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert((d.datacount_fg_color != 0) && (strcmp(d.datacount_fg_color, "[37m") == 0));
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "count-foreground: normal");
	fclose(tmp_rcfile);

	clear_errno();
	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "count-background: kjshdfkjh");
	fclose(tmp_rcfile);

	clear_errno();
	assert(test_parse_rc(out,1));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "count-background: black");
	fclose(tmp_rcfile);

	clear_errno();
	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert((d.datacount_bg_color != 0) && (strcmp(d.datacount_bg_color, "[40m") == 0));
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "count-background: red");
	fclose(tmp_rcfile);

	clear_errno();
	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert((d.datacount_bg_color != 0) && (strcmp(d.datacount_bg_color, "[41m") == 0));
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "count-background: green");
	fclose(tmp_rcfile);

	clear_errno();
	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert((d.datacount_bg_color != 0) && (strcmp(d.datacount_bg_color, "[42m") == 0));
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "count-background: yellow");
	fclose(tmp_rcfile);

	clear_errno();
	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert((d.datacount_bg_color != 0) && (strcmp(d.datacount_bg_color, "[43m") == 0));
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "count-background: blue");
	fclose(tmp_rcfile);

	clear_errno();
	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert((d.datacount_bg_color != 0) && (strcmp(d.datacount_bg_color, "[44m") == 0));
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "count-background: magenta");
	fclose(tmp_rcfile);

	clear_errno();
	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert((d.datacount_bg_color != 0) && (strcmp(d.datacount_bg_color, "[45m") == 0));
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "count-background: cyan");
	fclose(tmp_rcfile);

	clear_errno();
	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert((d.datacount_bg_color != 0) && (strcmp(d.datacount_bg_color, "[46m") == 0));
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "count-background: white");
	fclose(tmp_rcfile);

	clear_errno();
	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert((d.datacount_bg_color != 0) && (strcmp(d.datacount_bg_color, "[47m") == 0));
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "count-background: normal");
	fclose(tmp_rcfile);

	clear_errno();
	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "count-bold: Sjkhg");
	fclose(tmp_rcfile);

	clear_errno();
	assert(test_parse_rc(out,1));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "count-bold: no");
	fclose(tmp_rcfile);

	clear_errno();
	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "count-bold: yes");
	fclose(tmp_rcfile);

	clear_errno();
	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 1);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "count-bold: n");
	fclose(tmp_rcfile);

	clear_errno();
	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "count-bold: y");
	fclose(tmp_rcfile);

	clear_errno();
	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 1);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "count-bold: false");
	fclose(tmp_rcfile);

	clear_errno();
	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "count-bold: true");
	fclose(tmp_rcfile);

	clear_errno();
	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 1);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "count-bold: f");
	fclose(tmp_rcfile);

	clear_errno();
	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "count-bold: t");
	fclose(tmp_rcfile);

	clear_errno();
	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 1);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "count-bold: 0");
	fclose(tmp_rcfile);

	clear_errno();
	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "count-bold: 1");
	fclose(tmp_rcfile);

	clear_errno();
	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 1);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "count-bold: off");
	fclose(tmp_rcfile);

	clear_errno();
	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "count-bold: on");
	fclose(tmp_rcfile);

	clear_errno();
	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 1);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(unlink("./test-rcfile.txt") == 0);
}

void test142(FILE *out)
{
	FILE *tmp_rcfile = 0;

	unlink("./test-rcfile.txt");

	clear_errno();
	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 0);
	assert(d.twiddle_fg_color == 0);
	assert(d.twiddle_bg_color == 0);
	assert(d.twiddle_fg_bold == 0);
	assert(d.datacount_fg_color == 0);
	assert(d.datacount_bg_color == 0);
	assert(d.datacount_fg_bold == 0);
	assert(d.throughput_label_fg_color == 0);
	assert(d.throughput_label_bg_color == 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color == 0);
	assert(d.throughput_bg_color == 0);
	assert(d.throughput_fg_bold == 0);
	assert(d.time_label_fg_color == 0);
	assert(d.time_label_bg_color == 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color == 0);
	assert(d.percent_bg_color == 0);
	assert(d.percent_fg_bold == 0);
	assert(d.barbrace_fg_color == 0);
	assert(d.barbrace_bg_color == 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color == 0);
	assert(d.bar_bg_color == 0);
	assert(d.bar_fg_bold == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	tmp_rcfile = fopen("test-rcfile.txt", "w");
	assert(tmp_rcfile != 0);
	fprintf(tmp_rcfile, "# This is a comment\n");
	fprintf(tmp_rcfile, "display-twiddle: no\n");
	fprintf(tmp_rcfile, "display-ansi: yes\n");
	fprintf(tmp_rcfile, "space-background: black\n");
	fprintf(tmp_rcfile, "twiddle-foreground: green\n");
	fprintf(tmp_rcfile, "twiddle-background: red\n");
	fprintf(tmp_rcfile, "twiddle-bold: no\n");
	fprintf(tmp_rcfile, "count-foreground: yellow\n");
	fprintf(tmp_rcfile, "count-background: black\n");
	fprintf(tmp_rcfile, "count-bold: yes\n");
	fprintf(tmp_rcfile, "throughput-label-foreground: green\n");
	fprintf(tmp_rcfile, "throughput-label-background: red\n");
	fprintf(tmp_rcfile, "throughput-label-bold: no\n");
	fprintf(tmp_rcfile, "throughput-foreground: yellow\n");
	fprintf(tmp_rcfile, "throughput-background: black\n");
	fprintf(tmp_rcfile, "throughput-bold: yes\n");
	fprintf(tmp_rcfile, "time-label-foreground: green\n");
	fprintf(tmp_rcfile, "time-label-background: red\n");
	fprintf(tmp_rcfile, "time-label-bold: no\n");
	fprintf(tmp_rcfile, "time-foreground: yellow\n");
	fprintf(tmp_rcfile, "time-background: black\n");
	fprintf(tmp_rcfile, "time-bold: yes\n");
	fprintf(tmp_rcfile, "percent-foreground: yellow\n");
	fprintf(tmp_rcfile, "percent-background: green\n");
	fprintf(tmp_rcfile, "percent-bold: yes\n");
	fprintf(tmp_rcfile, "bar-brace-foreground: green\n");
	fprintf(tmp_rcfile, "bar-brace-background: blue\n");
	fprintf(tmp_rcfile, "bar-brace-bold: no\n");
	fprintf(tmp_rcfile, "bar-foreground: yellow\n");
	fprintf(tmp_rcfile, "bar-background: blue\n");
	fprintf(tmp_rcfile, "bar-bold: yes\n");
	fclose(tmp_rcfile);

	clear_errno();
	assert(test_parse_rc(out,0));

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 0);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(d.display_ansi == 1);
	assert((d.twiddle_fg_color != 0) && (strcmp(d.twiddle_fg_color, "[32m") == 0));
	assert((d.twiddle_bg_color != 0) && (strcmp(d.twiddle_bg_color, "[41m") == 0));
	assert(d.twiddle_fg_bold == 0);
	assert((d.datacount_fg_color != 0) && (strcmp(d.datacount_fg_color, "[33m") == 0));
	assert((d.datacount_bg_color != 0) && (strcmp(d.datacount_bg_color, "[40m") == 0));
	assert(d.datacount_fg_bold == 1);
	assert(d.throughput_label_fg_color != 0);
	assert(d.throughput_label_bg_color != 0);
	assert(d.throughput_label_fg_bold == 0);
	assert(d.throughput_fg_color != 0);
	assert(d.throughput_bg_color != 0);
	assert(d.throughput_fg_bold == 1);
	assert(d.time_label_fg_color != 0);
	assert(d.time_label_bg_color != 0);
	assert(d.time_label_fg_bold == 0);
	assert(d.percent_fg_color != 0);
	assert(d.percent_bg_color != 0);
	assert(d.percent_fg_bold == 1);
	assert(d.barbrace_fg_color != 0);
	assert(d.barbrace_bg_color != 0);
	assert(d.barbrace_fg_bold == 0);
	assert(d.bar_fg_color != 0);
	assert(d.bar_bg_color != 0);
	assert(d.bar_fg_bold == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(unlink("./test-rcfile.txt") == 0);
}

int main(int argc, char *argv[])
{
	FILE *out = stderr;

#ifndef PRINT_ERRORS
	out = fopen("/dev/null", "w");
	assert(out != 0);
#endif

	test1(out);
	test2(out);
	test3(out);
	test4(out);
	test5(out);
	test6(out);
	test7(out);
	test8(out);
	test9(out);
	test10(out);
	test11(out);
	test12(out);
	test13(out);
	test14(out);
	test15(out);
	test16(out);
	test17(out);
	test18(out);
	test19(out);
	test20(out);
	test21(out);
	test22(out);
	test23(out);
	test24(out);
	test25(out);
	test26(out);
	test27(out);
	test28(out);
	test29(out);
	test30(out);
	test31(out);
	test32(out);
	test33(out);
	test34(out);
	test35(out);
	test36(out);
	test37(out);
	test38(out);
	test39(out);
	test40(out);
	test41(out);
	test42(out);
	test43(out);
	test44(out);
	test45(out);
	test46(out);
	test47(out);
	test48(out);
	test49(out);
	test50(out);
	test51(out);
	test52(out);
	test53(out);
	test54(out);
	test55(out);
	test56(out);
	test57(out);
	test58(out);
	test59(out);
	test60(out);
	test61(out);
	test62(out);
	test63(out);
	test64(out);
	test65(out);
	test66(out);
	test67(out);
	test68(out);
	test69(out);
	test70(out);
	test71(out);
	test72(out);
	test73(out);
	test74(out);
	test75(out);
	test76(out);
	test77(out);
	test78(out);
	test79(out);
	test80(out);
	test81(out);
	test82(out);
	test83(out);
	test84(out);
	test85(out);
	test86(out);
	test87(out);
	test88(out);
	test89(out);
	test90(out);
	test91(out);
	test92(out);
	test93(out);
	test94(out);
	test95(out);
	test96(out);
	test97(out);
	test98(out);
	test99(out);
	test100(out);
	test101(out);
	test102(out);
	test103(out);
	test104(out);
	test105(out);
	test106(out);
	test107(out);
	test108(out);
	test109(out);
	test110(out);
	test111(out);
	test112(out);
	test113(out);
	test114(out);
	test115(out);
	test116(out);
	test117(out);
	test118(out);
	test119(out);
	test120(out);
	test121(out);
	test122(out);
	test123(out);
	test124(out);
	test125(out);
	test126(out);
	test127(out);
	test128(out);
	test129(out);
	test130(out);
	test131(out);
	test132(out);
	test133(out);
	test134(out);
	test135(out);
	test136(out);
	test137(out);
	test138(out);
	test139(out);
	test140(out);
	test141(out);
	test142(out);

#ifdef PRINT_ERRORS
	fclose(out);
#endif
	return(0);
}

